--------------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------
--
-- Brake, reverse and flasher lights
--
--------------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------
-- to modDesc.xml:
--   ...
--   ...
--   <specializations>
--     ...
--     ...
--     <specialization name="BRFlights" className="BRFlights" filename="BRFlights.lua"/>
--   </specializations>
--   <vehicleTypes>
--     <type name="???????" className="Vehicle" filename="$dataS/scripts/vehicles/Vehicle.lua">
--       ...
--       ...
--       <specialization name="BRFlights" />	
--     </type>
--   </vehicleTypes>
--   ...
--   ...
--   <inputBindings>
--     ...
--     ...
--     <input name="RIGHTTURN" key="KEY_KP_3" button="" />
--     <input name="LEFTTURN" key="KEY_KP_1" button="" />
--   </inputBindings>
--   ...
--   ... 
--------------------------------------------------------------------------------------------
-- to ???????.xml
--   <vehicle type="???????">
--     ...
--     ...
--     <reverselights index="0|5|1"/>
--     <brakelights index="0|5|2"/>
--     <flasherlights leftTurnIndex="0|5|3" rightTurnIndex="0|5|4" />
--     ...
--     ...
--   </vehicle>     
--------------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------------

BRFlights = {};

function BRFlights.prerequisitesPresent(specializations)
    return true;
end;

function BRFlights:load(xmlFile)
  if getXMLString(xmlFile, "vehicle.reverselights#index") ~= nil then
    self.reverseLightObject = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.reverselights#index"));
    setVisibility(self.reverseLightObject, false);
    self.reverseLightActive = false;
  end;

  if getXMLString(xmlFile, "vehicle.brakelights#index") ~= nil then
    self.brakeLightObject = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.brakelights#index"));
    setVisibility(self.brakeLightObject, false);
    self.brakeLightActive = false;
  end;
  
  if getXMLString(xmlFile, "vehicle.flasherlights#leftTurnIndex") ~= nil and getXMLString(xmlFile, "vehicle.flasherlights#rightTurnIndex") ~= nil then
    self.leftTurnObject = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flasherlights#leftTurnIndex"));
    setVisibility(self.leftTurnObject, false);
    self.leftTurnActive = false;
    self.flashLeft = false;
    
    self.rightTurnObject = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.flasherlights#rightTurnIndex"));
    setVisibility(self.rightTurnObject, false);
    self.rightTurnActive = false;
    self.flashRight = false;
    
    self.flashWarn = false;
    self.flashtimer = 10;
  end;  
end;

function BRFlights:delete()
end;

function BRFlights:mouseEvent(posX, posY, isDown, isUp, button)
end;

function BRFlights:keyEvent(unicode, sym, modifier, isDown)
  -- Flasher lights
  if InputBinding.isPressed(InputBinding.LEFTTURN) then
    if not self.flashLeft or self.flashWarn then
      self.flashLeft = false;
    end;
    self.flashLeft = not self.flashLeft;
    self.flashRight = false;
    self.flashWarn = false;
    self.flashtimer = 10;
  end;
  if InputBinding.isPressed(InputBinding.RIGHTTURN) then
    if not self.flashRight or self.flashWarn then
        self.flashRight = false;
    end;
    self.flashRight = not self.flashRight;
    self.flashLeft = false;
    self.flashWarn = false;
    self.flashtimer = 10;
  end;
  -- Warn lights
  if InputBinding.isPressed(InputBinding.WARNLIGHTS) then
    if self.flashWarn then
      self.flashLeft = false;
      self.flashRight = false;
    else
      self.rightTurnActive = false;
      self.leftTurnActive = false;
      self.flashLeft = true;
      self.flashRight = true;
    end;
    self.flashWarn = not self.flashWarn;
    self.flashtimer = 10;
  end;
end;

function BRFlights:update(dt)
  -- Reverse lights
  if self.reverseLightObject ~= nil then
    if self.movingDirection < 0 then
      self.reverseLightActive = true;
    else
      self.reverseLightActive = false;
    end;
    setVisibility(self.reverseLightObject, self.reverseLightActive);
  end;
  
  -- Brake lights
  if self.brakeLightObject ~= nil then
    local input = 0;
    if self:getIsActiveForInput() then
        input = InputBinding.getAnalogInputAxis(InputBinding.AXIS_FORWARD);
        if InputBinding.isAxisZero(input) then
          input = InputBinding.getDigitalInputAxis(InputBinding.AXIS_FORWARD);
        end;
    end;
  
    if (self.movingDirection*self.lastSpeed*(-input)) < -0.001 then
      self.brakeLightActive = true;
    else
      self.brakeLightActive = false;
    end;
    setVisibility(self.brakeLightObject, self.brakeLightActive);
  end;
  
	-- Flasher lights
	if self.rightTurnObject ~= nil and self.leftTurnObject ~= nil then
    if self.flashLeft or self.flashRight then
        self.flashtimer = self.flashtimer - dt;
        if self.flashRight or self.flashWarn then
            if self.flashtimer < 0 then
                self.rightTurnActive = not self.rightTurnActive;
            end;
        else
            self.rightTurnActive = false;
        end;
    
        if self.flashLeft or self.flashWarn then
            if self.flashtimer < 0 then
                self.leftTurnActive = not self.leftTurnActive;
            end;
        else
            self.leftTurnActive = false;
        end;
              
        if self.flashtimer < 0 then
            self.flashtimer = 500;
        end;
    else
        self.rightTurnActive = false;
        self.leftTurnActive = false;
    end;
    setVisibility(self.rightTurnObject, self.rightTurnActive);
    setVisibility(self.leftTurnObject, self.leftTurnActive);
  end;
end;

function BRFlights:draw()
end;


